diff --git a/flutter/lib/consts.dart b/flutter/lib/consts.dart
index 99130f892..26e25a209 100644
--- a/flutter/lib/consts.dart
+++ b/flutter/lib/consts.dart
@@ -109,8 +109,8 @@ const kRemoteImageQualityCustom = 'custom';
 /// [kRemoteAudioGuestToHost] Guest to host audio mode(default).
 const kRemoteAudioGuestToHost = 'guest-to-host';
 
-/// [kRemoteAudioTwoWay] two-way audio mode(default).
-const kRemoteAudioTwoWay = 'two-way';
+/// [kRemoteAudioDualWay] dual-way audio mode(default).
+const kRemoteAudioDualWay = 'dual-way';
 
 const kIgnoreDpi = true;
 
diff --git a/flutter/lib/desktop/widgets/remote_menubar.dart b/flutter/lib/desktop/widgets/remote_menubar.dart
index bb2079930..9864947c6 100644
--- a/flutter/lib/desktop/widgets/remote_menubar.dart
+++ b/flutter/lib/desktop/widgets/remote_menubar.dart
@@ -1115,8 +1115,8 @@ class _RemoteMenubarState extends State<RemoteMenubar> {
             dismissOnClicked: true,
           ),
           MenuEntryRadioOption(
-            text: translate('Two way'),
-            value: kRemoteAudioTwoWay,
+            text: translate('Dual way'),
+            value: kRemoteAudioDualWay,
             dismissOnClicked: true,
           ),
         ],
diff --git a/libs/hbb_common/protos/message.proto b/libs/hbb_common/protos/message.proto
index da4865069..48b999438 100644
--- a/libs/hbb_common/protos/message.proto
+++ b/libs/hbb_common/protos/message.proto
@@ -446,7 +446,7 @@ enum ImageQuality {
 
 enum AudioMode {
   GuestToHost = 0;
-  TwoWay = 1;
+  DualWay = 1;
 }
 
 message VideoCodecState {
diff --git a/src/client.rs b/src/client.rs
index d76f930c8..649b180bb 100644
--- a/src/client.rs
+++ b/src/client.rs
@@ -1262,8 +1262,8 @@ impl LoginConfigHandler {
     pub fn get_audio_mode_enum(q: &str, ignore_default: bool) -> Option<AudioMode> {
         if q == "guest-to-host" {
             Some(AudioMode::GuestToHost)
-        } else if q == "two-way" {
-            Some(AudioMode::TwoWay)
+        } else if q == "dual-way" {
+            Some(AudioMode::DualWay)
         } else {
             if ignore_default {
                 None
diff --git a/src/lang/ca.rs b/src/lang/ca.rs
index 197435158..e45dc5fb5 100644
--- a/src/lang/ca.rs
+++ b/src/lang/ca.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", ""),
         ("Other Default Options", ""),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/cn.rs b/src/lang/cn.rs
index c74f352ce..84bfcb384 100644
--- a/src/lang/cn.rs
+++ b/src/lang/cn.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", "自动"),
         ("Other Default Options", "其它默认选项"),
         ("Guest to Host", "被控到主机"),
-        ("Two way", "双向"),
+        ("Dual way", "双向"),
         ("Audio Transmission Mode", "音频传输模式"),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/cs.rs b/src/lang/cs.rs
index d956ddf53..ef9cd7bf8 100644
--- a/src/lang/cs.rs
+++ b/src/lang/cs.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", ""),
         ("Other Default Options", ""),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/da.rs b/src/lang/da.rs
index 9e771567a..32aa1f0af 100644
--- a/src/lang/da.rs
+++ b/src/lang/da.rs
@@ -437,7 +437,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Please confirm if you want to share your desktop?", ""),
         ("Closed as expected", ""),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
         ("Display", ""),
         ("Default View Style", ""),
diff --git a/src/lang/de.rs b/src/lang/de.rs
index a112385a6..f8fac0737 100644
--- a/src/lang/de.rs
+++ b/src/lang/de.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", "Automatisch"),
         ("Other Default Options", "Weitere Standardoptionen"),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/eo.rs b/src/lang/eo.rs
index 342eac51c..4aa2be8db 100644
--- a/src/lang/eo.rs
+++ b/src/lang/eo.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", ""),
         ("Other Default Options", ""),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/es.rs b/src/lang/es.rs
index 74acd8c69..932936da3 100644
--- a/src/lang/es.rs
+++ b/src/lang/es.rs
@@ -447,7 +447,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Other Default Options", "Otras opciones predeterminadas"),
         ("Closed as expected", ""),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/fa.rs b/src/lang/fa.rs
index 50e883227..b8c45fbee 100644
--- a/src/lang/fa.rs
+++ b/src/lang/fa.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", "خودکار"),
         ("Other Default Options", "سایر گزینه های پیش فرض"),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/fr.rs b/src/lang/fr.rs
index 9bfdb6b1e..64a8b4e40 100644
--- a/src/lang/fr.rs
+++ b/src/lang/fr.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", "Auto"),
         ("Other Default Options", "Autres options par défaut"),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/gr.rs b/src/lang/gr.rs
index a569b750f..3918db55b 100644
--- a/src/lang/gr.rs
+++ b/src/lang/gr.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", ""),
         ("Other Default Options", ""),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/hu.rs b/src/lang/hu.rs
index e28294de0..edad7ecd0 100644
--- a/src/lang/hu.rs
+++ b/src/lang/hu.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", ""),
         ("Other Default Options", ""),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/id.rs b/src/lang/id.rs
index ece6c9233..1b2dc4ad5 100644
--- a/src/lang/id.rs
+++ b/src/lang/id.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", ""),
         ("Other Default Options", ""),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/it.rs b/src/lang/it.rs
index e252219c1..27432303d 100644
--- a/src/lang/it.rs
+++ b/src/lang/it.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", "Auto"),
         ("Other Default Options", "Altre Opzioni Predefinite"),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/ja.rs b/src/lang/ja.rs
index 036bc8ec7..ae375b8ee 100644
--- a/src/lang/ja.rs
+++ b/src/lang/ja.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", ""),
         ("Other Default Options", ""),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/ko.rs b/src/lang/ko.rs
index 6da983849..417f88fe6 100644
--- a/src/lang/ko.rs
+++ b/src/lang/ko.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", ""),
         ("Other Default Options", ""),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/kz.rs b/src/lang/kz.rs
index 459139f58..e852278dd 100644
--- a/src/lang/kz.rs
+++ b/src/lang/kz.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", ""),
         ("Other Default Options", ""),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/pl.rs b/src/lang/pl.rs
index 483879d49..4cce52e08 100644
--- a/src/lang/pl.rs
+++ b/src/lang/pl.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", "Auto"),
         ("Other Default Options", "Inne opcje domyślne"),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/pt_PT.rs b/src/lang/pt_PT.rs
index cff00333a..29252926f 100644
--- a/src/lang/pt_PT.rs
+++ b/src/lang/pt_PT.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", ""),
         ("Other Default Options", ""),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/ptbr.rs b/src/lang/ptbr.rs
index 9fe5eab8c..8ec40cf13 100644
--- a/src/lang/ptbr.rs
+++ b/src/lang/ptbr.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", ""),
         ("Other Default Options", ""),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/ro.rs b/src/lang/ro.rs
index 36e2a99de..c4f798abf 100644
--- a/src/lang/ro.rs
+++ b/src/lang/ro.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", ""),
         ("Other Default Options", ""),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/ru.rs b/src/lang/ru.rs
index 31f24a5e8..949eba641 100644
--- a/src/lang/ru.rs
+++ b/src/lang/ru.rs
@@ -448,7 +448,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Please confirm if you want to share your desktop?", "Подтвердите, что хотите поделиться своим рабочим столом?"),
         ("Closed as expected", ""),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/sk.rs b/src/lang/sk.rs
index 8cf858df0..7de4d10ce 100644
--- a/src/lang/sk.rs
+++ b/src/lang/sk.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", ""),
         ("Other Default Options", ""),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/sl.rs b/src/lang/sl.rs
index 0e2208c3c..bf30f96d8 100755
--- a/src/lang/sl.rs
+++ b/src/lang/sl.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", ""),
         ("Other Default Options", ""),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/sq.rs b/src/lang/sq.rs
index 44159fb4a..db560166a 100644
--- a/src/lang/sq.rs
+++ b/src/lang/sq.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", ""),
         ("Other Default Options", ""),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/sr.rs b/src/lang/sr.rs
index 892b3664e..599cd651b 100644
--- a/src/lang/sr.rs
+++ b/src/lang/sr.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", ""),
         ("Other Default Options", ""),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/sv.rs b/src/lang/sv.rs
index 619a68508..c0616300c 100644
--- a/src/lang/sv.rs
+++ b/src/lang/sv.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", ""),
         ("Other Default Options", ""),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/template.rs b/src/lang/template.rs
index f0458b115..282b564d7 100644
--- a/src/lang/template.rs
+++ b/src/lang/template.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", ""),
         ("Other Default Options", ""),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/th.rs b/src/lang/th.rs
index f61ba325a..b2bee959a 100644
--- a/src/lang/th.rs
+++ b/src/lang/th.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", ""),
         ("Other Default Options", ""),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/tr.rs b/src/lang/tr.rs
index cade148a7..b6efeaf0a 100644
--- a/src/lang/tr.rs
+++ b/src/lang/tr.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", ""),
         ("Other Default Options", ""),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/tw.rs b/src/lang/tw.rs
index 46cc90c1e..eea71e6bf 100644
--- a/src/lang/tw.rs
+++ b/src/lang/tw.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", "自動"),
         ("Other Default Options", "其它默認選項"),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/ua.rs b/src/lang/ua.rs
index 7c355edd5..f0d85a551 100644
--- a/src/lang/ua.rs
+++ b/src/lang/ua.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", ""),
         ("Other Default Options", ""),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/lang/vn.rs b/src/lang/vn.rs
index f7640ae50..5e4009570 100644
--- a/src/lang/vn.rs
+++ b/src/lang/vn.rs
@@ -446,7 +446,7 @@ pub static ref T: std::collections::HashMap<&'static str, &'static str> =
         ("Auto", ""),
         ("Other Default Options", ""),
         ("Guest to Host", ""),
-        ("Two way", ""),
+        ("Dual way", ""),
         ("Audio Transmission Mode", ""),
     ].iter().cloned().collect();
 }
diff --git a/src/ui_session_interface.rs b/src/ui_session_interface.rs
index 73414e405..1e7848505 100644
--- a/src/ui_session_interface.rs
+++ b/src/ui_session_interface.rs
@@ -669,13 +669,6 @@ impl<T: InvokeUiSession> Session<T> {
             }
         }
     }
-
-    fn get_audio_transmission_mode(&self, id: &str) {
-
-    }
-    fn set_audio_transmission_mode(&self, id: &str, mode: String) {
-
-    }
 }
 
 pub trait InvokeUiSession: Send + Sync + Clone + 'static + Sized + Default {
diff --git a/src/client/io_loop.rs b/src/client/io_loop.rs
index af8c1048b..a284fdade 100644
--- a/src/client/io_loop.rs
+++ b/src/client/io_loop.rs
@@ -393,7 +393,7 @@ impl<T: InvokeUiSession> Remote<T> {
                             allow_err!(sender.send(()));
                         }
                     }
-                    AudioMode::TwoWay => {
+                    AudioMode::DualWay => {
                         // Start audio thread for playback.
                         // Cancel previous local audio session.
                         if let Some(sender) = self.stop_local_audio_sender.take() {
@@ -889,14 +889,15 @@ impl<T: InvokeUiSession> Remote<T> {
                             self.handler.load_last_jobs();
                         }
 
                         // Start audio thread for playback if current audio mode is two-way transmission.
                         if !self.handler.is_file_transfer() && !self.handler.is_port_forward() {
                             let audio_mode = LoginConfigHandler::get_audio_mode_enum(
                                 self.handler.load_config().audio_mode.as_str(),
                                 false,
                             )
                             .unwrap_or(AudioMode::GuestToHost);
-                            if audio_mode == AudioMode::TwoWay {
+                            log::debug!("current audio mode: {:?}", audio_mode);
+                            if audio_mode == AudioMode::DualWay {
                                 // Cancel previous local audio session.
                                 if let Some(sender) = self.stop_local_audio_sender.take() {
                                     allow_err!(sender.send(()));
@@ -889,14 +889,15 @@ impl<T: InvokeUiSession> Remote<T> {
                         }
 
-                        // Start audio thread for playback if current audio mode is two-way transmission.
+                        // Start audio thread for playback if current audio mode is dual-way transmission.
                         if !self.handler.is_file_transfer() && !self.handler.is_port_forward() {
                             let audio_mode = LoginConfigHandler::get_audio_mode_enum(